<?php

namespace Drupal\feature_toggle;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\State\StateInterface;

/**
 * Provides convenience methods for feature toggle services.
 */
trait FeatureUtilsTrait {

  /**
   * Drupal\Core\State\State definition.
   *
   * @var \Drupal\Core\State\StateInterface
   */
  protected $state;

  /**
   * The config object.
   *
   * @var \Drupal\Core\Config\Config
   */
  protected $config;

  /**
   * Constructs a new FeatureUtilsTrait object.
   */
  public function __construct(StateInterface $state, ConfigFactoryInterface $config_factory) {
    $this->state = $state;
    $this->config = $config_factory->getEditable('feature_toggle.features');
  }

  /**
   * Returns the list of features.
   *
   * @return array
   *   The list of features i nthe system.
   */
  protected function loadFeatures() {
    return $this->config->get('features');
  }

  /**
   * Saves the features array.
   *
   * @param array $features
   *   The features array.
   */
  protected function saveFeatures(array $features) {
    $this->config->set('features', $features)->save();
  }

  /**
   * Returns the system status flags.
   *
   * @return array
   *   The status flags array.
   */
  protected function getStatusFlags() {
    $features = $this->state->get('feature_toggle_flags', []);
    return $features;
  }

  /**
   * Saves the status flags array.
   *
   * @param array $flags
   *   The status flags array.
   */
  protected function saveStatusFlags(array $flags) {
    $this->state->set('feature_toggle_flags', $flags);
  }

}
